aacgmv2
=======

These functions are available when you ``import aacgmv2``.

.. automodule:: aacgmv2
    :members:

.. automodule:: aacgmv2.wrapper
    :members:

.. automodule:: aacgmv2.deprecated
    :members:
		
